/* eslint-disable camelcase */
// with polyfills
import 'core-js/stable'
import 'regenerator-runtime/runtime'
import './public-path'
import Vue from 'vue'
import App from './App.vue'
import router from './router'
import permission from './directive/permission'
import style from './directive/style'
import store from './store/'
import i18n from './locales'
import { VueAxios } from './utils/request'
import ProLayout, { PageHeaderWrapper } from '@/components/ProLayout'
import FooterToolBar from '@/components/FooterToolbar'
import FileUpload from '@/components/FileUpload'
import themePluginConfig from '../config/themePluginConfig'
import '@/assets/button/index.less'
import '@/assets/globalTableStyle/filterTable.less'
import '@/assets/reWthiteStyle/index.less'
// mock
// WARNING: `mockjs` NOT SUPPORT `IE` PLEASE DO NOT USE IN `production` ENV.
// import './mock'
// import ElementUI from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'

import Avue from 'cenform/lib/avue.min.js'
import 'cenform/lib/index.css'

// import AvueFormDesign from '@sscfaith/avue-form-design'
import AvueFormDesign from '../packages/'

import bootstraps from './core/bootstrap'
import './core/lazy_use' // use lazy load components
import './core/lazy_ele' // use lazy load components
import './permission' // permission control
import './utils/filter' // global filter
import './global.less' // global style
import config from '@/config/defaultSettings'
import { getDicts } from '@/api/system/dict/data'
import { getConfigKey } from '@/api/system/config'
import { parseTime, resetForm, addDateRange, selectDictLabel, selectDictLabels, download, handleTree, changekey } from '@/utils/ruoyi'

// 全局方法挂载
Vue.prototype.getDicts = getDicts
Vue.prototype.getConfigKey = getConfigKey
Vue.prototype.parseTime = parseTime
Vue.prototype.resetForm = resetForm
Vue.prototype.addDateRange = addDateRange
Vue.prototype.selectDictLabel = selectDictLabel
Vue.prototype.selectDictLabels = selectDictLabels
Vue.prototype.download = download
Vue.prototype.handleTree = handleTree
Vue.prototype.changekey = changekey
Vue.prototype.$EventBus = new Vue()
Vue.prototype.tableSize = config.tableSize
Vue.config.productionTip = false

// mount axios to `Vue.$http` and `this.$http`
Vue.use(VueAxios)
// use pro-layout components
// Vue.use(ElementUI)
Vue.use(Avue)
Vue.use(AvueFormDesign)

Vue.component('pro-layout', ProLayout)
Vue.component('page-container', PageHeaderWrapper)
Vue.component('page-header-wrapper', PageHeaderWrapper)
Vue.component('footer-tool-bar', FooterToolBar)
Vue.component('file-upload', FileUpload)

Vue.use(permission)
Vue.use(style)

window.umi_plugin_ant_themeVar = themePluginConfig.theme
let instance = null

function render(props = {}) {
  const { container } = props

  instance = new Vue({
    router,
    store,
    i18n,
    created: bootstraps,
    render: h => h(App)
  }).$mount(container ? container.querySelector('#app') : '#app')
}

if (window.__POWERED_BY_QIANKUN__) {
  // eslint-disable-next-line no-undef
  __webpack_public_path__ = window.__INJECTED_PUBLIC_PATH_BY_QIANKUN__
}

if (!window.__POWERED_BY_QIANKUN__) {
  render()
}

export async function bootstrap() {
  console.log('[vue] vue app bootstraped')
}

export async function mount(props) {
  console.log('[vue] props from main framework', props)
  // storeTest(props);
  render(props)
}

export async function unmount() {
  instance.$destroy()
  instance.$el.innerHTML = ''
  instance = null
  router = null
}
